@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package Raisin;
-$Raisin::VERSION = '0.90';
+$Raisin::VERSION = '0.91';
 use Carp qw(croak carp longmess);
 use HTTP::Status qw(:constants);
 use Plack::Response;
@@ -315,7 +315,7 @@ Raisin - A REST API microframework for Perl.
 
 =head1 VERSION
 
-version 0.90
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -1204,7 +1204,7 @@ which was inspired by L<Dancer>, which in its turn was inspired by Sinatra.
 
 =head1 AUTHOR
 
-Artur Khabibullin <rtkh@cpan.org>
+Artur Khabibullin
 
 =head1 COPYRIGHT AND LICENSE
 
