@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package Raisin::Encoder::JSON;
-$Raisin::Encoder::JSON::VERSION = '0.90';
+$Raisin::Encoder::JSON::VERSION = '0.91';
 use JSON::MaybeXS qw();
 
 my $json = JSON::MaybeXS->new(utf8 => 1);
@@ -33,7 +33,7 @@ Raisin::Encoder::JSON - JSON serialization plugin for Raisin.
 
 =head1 VERSION
 
-version 0.90
+version 0.91
 
 =head1 DESCRIPTION
 
@@ -41,7 +41,7 @@ Provides C<content_type>, C<serialize> methods.
 
 =head1 AUTHOR
 
-Artur Khabibullin <rtkh@cpan.org>
+Artur Khabibullin
 
 =head1 COPYRIGHT AND LICENSE
 
