@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package Raisin::Encoder::YAML;
-$Raisin::Encoder::YAML::VERSION = '0.90';
+$Raisin::Encoder::YAML::VERSION = '0.91';
 use Encode qw(encode_utf8 decode_utf8);
 use YAML qw(Dump Load);
 
@@ -29,7 +29,7 @@ Raisin::Encoder::YAML - YAML serialization plugin for Raisin.
 
 =head1 VERSION
 
-version 0.90
+version 0.91
 
 =head1 DESCRIPTION
 
@@ -37,7 +37,7 @@ Provides C<content_type>, C<serialize> methods.
 
 =head1 AUTHOR
 
-Artur Khabibullin <rtkh@cpan.org>
+Artur Khabibullin
 
 =head1 COPYRIGHT AND LICENSE
 
