@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package Raisin::Plugin::Logger;
-$Raisin::Plugin::Logger::VERSION = '0.90';
+$Raisin::Plugin::Logger::VERSION = '0.91';
 use parent 'Raisin::Plugin';
 
 use Carp qw(carp);
@@ -63,7 +63,7 @@ Raisin::Plugin::Logger - Logger plugin for Raisin.
 
 =head1 VERSION
 
-version 0.90
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -82,7 +82,7 @@ or L<Raisin::Logger> C<log> method.
 
 =head1 AUTHOR
 
-Artur Khabibullin <rtkh@cpan.org>
+Artur Khabibullin
 
 =head1 COPYRIGHT AND LICENSE
 
